C$$$  SUBPROGRAM DOCUMENTATION BLOCK
C                .      .    .                                       .
C SUBPROGRAM:    M_DEWPNT    COMPUTE DEWPNT GIVEN TEMP AND RH
C   PRGMMR: M. BARTH         ORG: FSL        DATE: 99-09-20
C
C ABSTRACT: FUNCTION TO RETURN THE DEW POINT GIVEN TEMPERATURE
C   AND RELATIVE HUMIDITY.
C
C PROGRAM HISTORY LOG:
C   82        DON BAKER    ORIGINAL VERSION
C   99-09-20  M. BARTH     COPIED FROM MSAS & MODIFIED FOR MADIS.
C
C USAGE:    M_DEWPNT(TK,RH,SPVAL)
C
C   INPUT ARGUMENT LIST:
C     TK       - REAL    TEMPERATURE (KELVIN)
C     RH       - REAL    RELATIVE HUMIDITY (PERCENT)
C     SPVAL    - REAL    MISSING DATA FLAG
C
C   OUTPUT ARGUMENT LIST:
C     M_DEWPNT - REAL    (KELVIN)
C
C REMARKS:
C   THIS FUNCTION RETURNS THE DEW POINT (KELVIN) GIVEN THE TEMPERATURE
C   (KELVIN) AND RELATIVE HUMIDITY (%). THE FORMULA IS USED IN THE
C   PROCESSING OF U.S. RAWINSONDE DATA AND IS REFERENCED IN PARRY, H.
C   DEAN, 1969: "THE SEMIAUTOMATIC COMPUTATION OF RAWINSONDES,"
C   TECHNICAL MEMORANDUM WBTM EDL 10, U.S. DEPARTMENT OF COMMERCE,
C   ENVIRONMENTAL SCIENCE SERVICES ADMINISTRATION, WEATHER BUREAU,
C   OFFICE OF SYSTEMS DEVELOPMENT, EQUIPMENT DEVELOPMENT LABORATORY,
C   SILVER SPRING, MD (OCTOBER), PAGE 9 AND PAGE II-4, LINE 460.
C
C ATTRIBUTES:
C   LANGUAGE: FORTRAN-77
C   MACHINE:  NAS-9000
C$$$
C*******************************************************
C
      REAL FUNCTION M_DEWPNT(TK,RH,SPVAL)

      INCLUDE 'IMPLICIT'
      REAL TK,RH,SPVAL,T,X,DPD,DWPTC

      IF(TK.NE.SPVAL.AND.RH.NE.SPVAL)THEN
         IF(TK.GT.150.) THEN
            T = TK -273.15
         ELSE
            T = TK
         ENDIF
         X = 1.-0.01*RH

C     COMPUTE DEW POINT DEPRESSION.

         DPD =(14.55+0.114*T)*X+((2.5+0.007*T)*X)**3+
     1        (15.9+0.117*T)*X**14
         DWPTC = T-DPD
         M_DEWPNT= DWPTC + 273.15
      ELSE
         M_DEWPNT = SPVAL
      ENDIF

      RETURN
      END
C**---------------------------------------------------------------------
C**REQUIRED STANDARD FSL DISCLAIMER (NOVEMBER 2000)
C**---------------------------------------------------------------------
C**  OPEN SOURCE LICENSE/DISCLAIMER,  FORECAST SYSTEMS LABORATORY
C**  NOAA/OAR/FSL, 325 BROADWAY BOULDER, CO 80305
C**
C**  THIS SOFTWARE IS DISTRIBUTED UNDER THE OPEN SOURCE DEFINITION, 
C**  WHICH MAY BE FOUND AT http://www.opensource.org/osd.html.
C**
C**  IN PARTICULAR, REDISTRIBUTION AND USE IN SOURCE AND BINARY FORMS,
C**  WITH OR WITHOUT MODIFICATION, ARE PERMITTED PROVIDED THAT THE 
C**  FOLLOWING CONDITIONS ARE MET:
C**
C**  - REDISTRIBUTIONS OF SOURCE CODE MUST RETAIN THIS NOTICE, THIS LIST
C**    OF CONDITIONS AND THE FOLLOWING DISCLAIMER.
C**
C**  - REDISTRIBUTIONS IN BINARY FORM MUST PROVIDE ACCESS TO THIS 
C**    NOTICE, THIS LIST OF CONDITIONS AND THE FOLLOWING DISCLAIMER, AND
C**    THE UNDERLYING SOURCE CODE.
C**
C**  - ALL MODIFICATIONS TO THIS SOFTWARE MUST BE CLEARLY DOCUMENTED, 
C**    AND ARE SOLELY THE RESPONSIBILITY OF THE AGENT MAKING THE 
C**    MODIFICATIONS.
C**
C**  - IF SIGNIFICANT MODIFICATIONS OR ENHANCEMENTS ARE MADE TO THIS
C**    SOFTWARE, THE FSL SOFTWARE POLICY MANAGER 
C**    (softwaremgr.fsl@noaa.gov) BE NOTIFIED.
C**
C**  THIS SOFTWARE AND ITS DOCUMENTATION ARE IN THE PUBLIC DOMAIN AND 
C**  ARE FURNISHED "AS IS."  THE AUTHORS, THE UNITED STATES GOVERNMENT,
C**  ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO 
C**  WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE
C**  AND DOCUMENTATION FOR ANY PURPOSE.  THEY ASSUME NO RESPONSIBILITY 
C**  (1) FOR THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO 
C**  PROVIDE TECHNICAL SUPPORT TO USERS.
C**---------------------------------------------------------------------
